@@ -1,27 +1,27 @@
 -- --------------------------------------------------------
 -- SQL Commands to set up the pmadb as described in the documentation.
--- 
+--
 -- This file is meant for use with Drizzle 2011.03.13 and above!
--- 
+--
 -- This script expects that you take care of database permissions.
 --
 -- Please don't forget to set up the tablenames in config.inc.php
--- 
+--
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Database : `phpmyadmin`
--- 
+--
 CREATE DATABASE IF NOT EXISTS `phpmyadmin`
   COLLATE utf8_bin;
 USE phpmyadmin;
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Table structure for table `pma__bookmark`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__bookmark` (
   `id` int(11) NOT NULL auto_increment,
@@ -36,9 +36,9 @@ CREATE TABLE IF NOT EXISTS `pma__bookmark` (
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Table structure for table `pma__column_info`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__column_info` (
   `id` int(5) NOT NULL auto_increment,
@@ -49,6 +49,8 @@ CREATE TABLE IF NOT EXISTS `pma__column_info` (
   `mimetype` varchar(255) COLLATE utf8_general_ci NOT NULL default '',
   `transformation` varchar(255) NOT NULL default '',
   `transformation_options` varchar(255) NOT NULL default '',
+  `input_transformation` varchar(255) NOT NULL default '',
+  `input_transformation_options` varchar(255) NOT NULL default '',
   PRIMARY KEY  (`id`),
   UNIQUE KEY `db_name` (`db_name`,`table_name`,`column_name`)
 )
@@ -57,9 +59,9 @@ CREATE TABLE IF NOT EXISTS `pma__column_info` (
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Table structure for table `pma__history`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__history` (
   `id` bigint(20) NOT NULL auto_increment,
@@ -76,9 +78,9 @@ CREATE TABLE IF NOT EXISTS `pma__history` (
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Table structure for table `pma__pdf_pages`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__pdf_pages` (
   `db_name` varchar(64) NOT NULL default '',
@@ -123,9 +125,9 @@ CREATE TABLE IF NOT EXISTS `pma__table_uiprefs` (
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Table structure for table `pma__relation`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__relation` (
   `master_db` varchar(64) NOT NULL default '',
@@ -142,9 +144,9 @@ CREATE TABLE IF NOT EXISTS `pma__relation` (
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Table structure for table `pma__table_coords`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__table_coords` (
   `db_name` varchar(64) NOT NULL default '',
@@ -159,9 +161,9 @@ CREATE TABLE IF NOT EXISTS `pma__table_coords` (
 
 -- --------------------------------------------------------
 
--- 
+--
 -- Table structure for table `pma__table_info`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__table_info` (
   `db_name` varchar(64) NOT NULL default '',
@@ -174,27 +176,9 @@ CREATE TABLE IF NOT EXISTS `pma__table_info` (
 
 -- --------------------------------------------------------
 
--- 
--- Table structure for table `pma__designer_coords`
--- 
-
-CREATE TABLE IF NOT EXISTS `pma__designer_coords` (
-  `db_name` varchar(64) NOT NULL default '',
-  `table_name` varchar(64) NOT NULL default '',
-  `x` INT,
-  `y` INT,
-  `v` INT,
-  `h` INT,
-  PRIMARY KEY (`db_name`,`table_name`)
-)
-  COMMENT='Table coordinates for Designer'
-  COLLATE utf8_bin;
-
--- --------------------------------------------------------
-
--- 
+--
 -- Table structure for table `pma__tracking`
--- 
+--
 
 CREATE TABLE IF NOT EXISTS `pma__tracking` (
   `db_name` varchar(64) NOT NULL,
@@ -236,7 +220,7 @@ CREATE TABLE IF NOT EXISTS `pma__users` (
   `username` varchar(64) NOT NULL,
   `usergroup` varchar(64) NOT NULL,
   PRIMARY KEY (`username`,`usergroup`)
-) 
+)
   COMMENT='Users and their assignments to user groups'
   COLLATE utf8_bin;
 
@@ -251,10 +235,10 @@ CREATE TABLE IF NOT EXISTS `pma__usergroups` (
   `tab` varchar(64) NOT NULL,
   `allowed` enum('Y','N') NOT NULL DEFAULT 'N',
   PRIMARY KEY (`usergroup`,`tab`,`allowed`)
-) 
+)
   COMMENT='User groups with configured menu items'
   COLLATE utf8_bin;
-  
+
 -- --------------------------------------------------------
 
 --
@@ -268,6 +252,24 @@ CREATE TABLE IF NOT EXISTS `pma__navigationhiding` (
   `db_name` varchar(64) NOT NULL,
   `table_name` varchar(64) NOT NULL,
   PRIMARY KEY (`username`,`item_name`,`item_type`,`db_name`,`table_name`)
-) 
+)
   COMMENT='Hidden items of navigation tree'
   COLLATE utf8_bin;
+
+-- --------------------------------------------------------
+
+--
+-- Table structure for table `pma__savedsearches`
+--
+
+CREATE TABLE IF NOT EXISTS `pma__savedsearches` (
+  `id` int(5) unsigned NOT NULL auto_increment,
+  `username` varchar(64) NOT NULL default '',
+  `db_name` varchar(64) NOT NULL default '',
+  `search_name` varchar(64) NOT NULL default '',
+  `search_data` text NOT NULL,
+  PRIMARY KEY  (`id`),
+  UNIQUE KEY `u_savedsearches_username_dbname` (`username`,`db_name`,`search_name`)
+)
+  COMMENT='Saved searches'
+  DEFAULT CHARACTER SET utf8 COLLATE utf8_bin;
