@@ -24,7 +24,7 @@ class PMA_Table
     const PROP_COLUMN_ORDER = 'col_order';
     const PROP_COLUMN_VISIB = 'col_visib';
 
-    static $cache = array();
+    static public $cache = array();
 
     /**
      * @var string  table name
@@ -192,9 +192,15 @@ class PMA_Table
 
         // use cached data or load information with SHOW command
         if (isset(PMA_Table::$cache[$db][$table])
+            || $GLOBALS['cfg']['Server']['DisableIS']
         ) {
             $type = PMA_Table::sGetStatusInfo($db, $table, 'TABLE_TYPE');
-            return $type == 'VIEW';
+            return $type == 'VIEW' || $type == 'SYSTEM VIEW';
+        }
+
+        // information_schema tables are 'SYSTEM VIEW's
+        if ($db == 'information_schema') {
+            return true;
         }
 
         // query information_schema
@@ -260,9 +266,12 @@ class PMA_Table
                 WHERE TABLE_SCHEMA = '" . PMA_Util::sqlAddSlashes($db) . "'
                 AND TABLE_NAME = '" . PMA_Util::sqlAddSlashes($table) . "'"
             );
+
             foreach ($results as $result) {
                 $analyzed_sql[0]['create_table_fields'][$result['COLUMN_NAME']]
-                    = array('type' => strtoupper($result['DATA_TYPE']));
+                    = array(
+                        'type' => /*overload*/mb_strtoupper($result['DATA_TYPE'])
+                    );
             }
         } else {
             $show_create_table = $GLOBALS['dbi']->fetchValue(
@@ -333,23 +342,10 @@ class PMA_Table
         }
 
         // any of known merge engines?
-        return in_array(strtoupper($engine), array('MERGE', 'MRG_MYISAM'));
-    }
-
-    /**
-     * Returns tooltip for the table
-     * Format : <table_comment> (<number_of_rows>)
-     *
-     * @param string $db    database name
-     * @param string $table table name
-     *
-     * @return string tooltip fot the table
-     */
-    static public function sGetToolTip($db, $table)
-    {
-        return PMA_Table::sGetStatusInfo($db, $table, 'Comment')
-            . ' (' . PMA_Table::countRecords($db, $table)
-            . ' ' . __('Rows') . ')';
+        return in_array(
+            /*overload*/mb_strtoupper($engine),
+            array('MERGE', 'MRG_MYISAM')
+        );
     }
 
     /**
@@ -374,10 +370,10 @@ class PMA_Table
             $disable_error = true;
         }
 
+        // sometimes there is only one entry (ExactRows) so
+        // we have to get the table's details
         if (! isset(PMA_Table::$cache[$db][$table])
             || $force_read
-            // sometimes there is only one entry (ExactRows) so
-            // we have to get the table's details
             || count(PMA_Table::$cache[$db][$table]) == 1
         ) {
             $GLOBALS['dbi']->getTablesFull($db, $table);
@@ -398,7 +394,7 @@ class PMA_Table
         if (!array_key_exists($info, PMA_Table::$cache[$db][$table])) {
             if (! $disable_error) {
                 trigger_error(
-                    __('unknown table status: ') . $info,
+                    __('Unknown table status:') . ' ' . $info,
                     E_USER_WARNING
                 );
             }
@@ -438,17 +434,22 @@ class PMA_Table
         $default_type = 'USER_DEFINED', $default_value = '',  $extra = '',
         $comment = '', &$field_primary = null, $move_to = ''
     ) {
-        $is_timestamp = strpos(strtoupper($type), 'TIMESTAMP') !== false;
+        $is_timestamp = /*overload*/mb_strpos(
+            /*overload*/mb_strtoupper($type),
+            'TIMESTAMP'
+        ) !== false;
 
         $query = PMA_Util::backquote($name) . ' ' . $type;
 
-        if ($length != ''
-            && ! preg_match(
-                '@^(DATE|DATETIME|TIME|TINYBLOB|TINYTEXT|BLOB|TEXT|'
-                . 'MEDIUMBLOB|MEDIUMTEXT|LONGBLOB|LONGTEXT|SERIAL|BOOLEAN|UUID)$@i',
-                $type
-            )
-        ) {
+        // allow the possibility of a length for TIME, DATETIME and TIMESTAMP
+        // (will work on MySQL >= 5.6.4)
+        //
+        // MySQL permits a non-standard syntax for FLOAT and DOUBLE,
+        // see http://dev.mysql.com/doc/refman/5.5/en/floating-point-types.html
+        //
+        $pattern = '@^(DATE|TINYBLOB|TINYTEXT|BLOB|TEXT|'
+            . 'MEDIUMBLOB|MEDIUMTEXT|LONGBLOB|LONGTEXT|SERIAL|BOOLEAN|UUID)$@i';
+        if ($length != '' && ! preg_match($pattern, $type)) {
             $query .= '(' . $length . ')';
         }
 
@@ -498,11 +499,12 @@ class PMA_Table
             }
             break;
         case 'NULL' :
-            //If user uncheck null checkbox and not change default value null,
-            //default value will be ignored.
-            if ($null !== false && $null != 'NULL') {
+            // If user uncheck null checkbox and not change default value null,
+            // default value will be ignored.
+            if ($null !== false && $null !== 'NULL') {
                 break;
             }
+            // else fall-through intended, no break here
         case 'CURRENT_TIMESTAMP' :
             $query .= ' DEFAULT ' . $default_type;
             break;
@@ -513,35 +515,6 @@ class PMA_Table
 
         if (!empty($extra)) {
             $query .= ' ' . $extra;
-            // Force an auto_increment field to be part of the primary key
-            // even if user did not tick the PK box;
-            if ($extra == 'AUTO_INCREMENT') {
-                $primary_cnt = count($field_primary);
-                if (1 == $primary_cnt) {
-                    for ($j = 0; $j < $primary_cnt; $j++) {
-                        if ($field_primary[$j] == $index) {
-                            break;
-                        }
-                    }
-                    if (isset($field_primary[$j]) && $field_primary[$j] == $index) {
-                        $query .= ' PRIMARY KEY';
-                        unset($field_primary[$j]);
-                    }
-                } else {
-                    // but the PK could contain other columns so do not append
-                    // a PRIMARY KEY clause, just add a member to $field_primary
-                    $found_in_pk = false;
-                    for ($j = 0; $j < $primary_cnt; $j++) {
-                        if ($field_primary[$j] == $index) {
-                            $found_in_pk = true;
-                            break;
-                        }
-                    } // end for
-                    if (! $found_in_pk) {
-                        $field_primary[] = $index;
-                    }
-                }
-            } // end if (auto_increment)
         }
         if (!empty($comment)) {
             $query .= " COMMENT '" . PMA_Util::sqlAddSlashes($comment) . "'";
@@ -821,7 +794,7 @@ class PMA_Table
 
         $source = PMA_Util::backquote($source_db)
             . '.' . PMA_Util::backquote($source_table);
-        if (! isset($target_db) || ! strlen($target_db)) {
+        if (! isset($target_db) || ! /*overload*/mb_strlen($target_db)) {
             $target_db = $source_db;
         }
 
@@ -883,7 +856,8 @@ class PMA_Table
                 );
                 // ANSI_QUOTES might be a subset of sql_mode, for example
                 // REAL_AS_FLOAT,PIPES_AS_CONCAT,ANSI_QUOTES,IGNORE_SPACE,ANSI
-                if (false !== strpos($server_sql_mode, 'ANSI_QUOTES')) {
+                if (false !== /*overload*/mb_strpos($server_sql_mode, 'ANSI_QUOTES')
+                ) {
                     $table_delimiter = 'quote_double';
                 } else {
                     $table_delimiter = 'quote_backtick';
@@ -923,7 +897,6 @@ class PMA_Table
             /* Generate query back */
             $sql_structure = PMA_SQP_format($parsed_sql, 'query_only');
             // If table exists, and 'add drop table' is selected: Drop it!
-            $drop_query = '';
             if (isset($_REQUEST['drop_if_exists'])
                 && $_REQUEST['drop_if_exists'] == 'true'
             ) {
@@ -974,8 +947,9 @@ class PMA_Table
                 $cnt = $parsed_sql['len'] - 1;
 
                 for ($j = $i; $j < $cnt; $j++) {
+                    $dataUpper = /*overload*/mb_strtoupper($parsed_sql[$j]['data']);
                     if ($parsed_sql[$j]['type'] == 'alpha_reservedWord'
-                        && strtoupper($parsed_sql[$j]['data']) == 'CONSTRAINT'
+                        && $dataUpper == 'CONSTRAINT'
                     ) {
                         if ($parsed_sql[$j+1]['type'] == $table_delimiter) {
                             $parsed_sql[$j+1]['data'] = '';
@@ -995,6 +969,73 @@ class PMA_Table
                     unset($GLOBALS['sql_constraints_query']);
                 }
             }
+
+            // add indexes to the table
+            if (!empty($GLOBALS['sql_indexes'])) {
+                $parsed_sql =  PMA_SQP_parse($GLOBALS['sql_indexes']);
+                $i = 0;
+
+                while ($parsed_sql[$i]['type'] != $table_delimiter) {
+                    $i++;
+                }
+
+                $parsed_sql[$i]['data'] = $target;
+
+                $cnt = $parsed_sql['len'] - 1;
+
+                for ($j = $i; $j < $cnt; $j++) {
+                    $dataUpper = /*overload*/mb_strtoupper($parsed_sql[$j]['data']);
+                    if ($parsed_sql[$j]['type'] == 'alpha_reservedWord'
+                        && $dataUpper == 'CONSTRAINT'
+                    ) {
+                        if ($parsed_sql[$j+1]['type'] == $table_delimiter) {
+                            $parsed_sql[$j+1]['data'] = '';
+                        }
+                    }
+                }
+                $GLOBALS['sql_indexes'] = PMA_SQP_format(
+                    $parsed_sql, 'query_only'
+                );
+                if ($mode == 'one_table' || $mode == 'db_copy') {
+                    $GLOBALS['dbi']->query($GLOBALS['sql_indexes']);
+                }
+                $GLOBALS['sql_query'] .= "\n" . $GLOBALS['sql_indexes'];
+                if ($mode == 'one_table' || $mode == 'db_copy') {
+                    unset($GLOBALS['sql_indexes']);
+
+                }
+            }
+
+            /*
+             * add AUTO_INCREMENT to the table
+             *
+             * @todo refactor with similar code above
+             */
+            if (! empty($GLOBALS['sql_auto_increments'])) {
+                if ($mode == 'one_table' || $mode == 'db_copy') {
+                    $parsed_sql =  PMA_SQP_parse($GLOBALS['sql_auto_increments']);
+                    $i = 0;
+
+                    // find the first $table_delimiter, it must be the source
+                    // table name
+                    while ($parsed_sql[$i]['type'] != $table_delimiter) {
+                        $i++;
+                    }
+
+                    // replace it by the target table name, no need
+                    // to backquote()
+                    $parsed_sql[$i]['data'] = $target;
+
+                    // Generate query back
+                    $GLOBALS['sql_auto_increments'] = PMA_SQP_format(
+                        $parsed_sql, 'query_only'
+                    );
+                    $GLOBALS['dbi']->query($GLOBALS['sql_auto_increments']);
+                    $GLOBALS['sql_query'] .= "\n" . $GLOBALS['sql_auto_increments'];
+                    unset($GLOBALS['sql_auto_increments']);
+                }
+            }
+
         } else {
             $GLOBALS['sql_query'] = '';
         }
@@ -1062,18 +1103,36 @@ class PMA_Table
                     );
 
                     // Write every comment as new copied entry. [MIME]
-                    while ($comments_copy_row = $GLOBALS['dbi']->fetchAssoc($comments_copy_rs)) {
-                        $new_comment_query = 'REPLACE INTO ' . PMA_Util::backquote($GLOBALS['cfgRelation']['db']) . '.' . PMA_Util::backquote($GLOBALS['cfgRelation']['column_info'])
-                                    . ' (db_name, table_name, column_name, comment' . ($GLOBALS['cfgRelation']['mimework'] ? ', mimetype, transformation, transformation_options' : '') . ') '
-                                    . ' VALUES('
-                                    . '\'' . PMA_Util::sqlAddSlashes($target_db) . '\','
-                                    . '\'' . PMA_Util::sqlAddSlashes($target_table) . '\','
-                                    . '\'' . PMA_Util::sqlAddSlashes($comments_copy_row['column_name']) . '\''
-                                    . ($GLOBALS['cfgRelation']['mimework'] ? ',\'' . PMA_Util::sqlAddSlashes($comments_copy_row['comment']) . '\','
-                                            . '\'' . PMA_Util::sqlAddSlashes($comments_copy_row['mimetype']) . '\','
-                                            . '\'' . PMA_Util::sqlAddSlashes($comments_copy_row['transformation']) . '\','
-                                            . '\'' . PMA_Util::sqlAddSlashes($comments_copy_row['transformation_options']) . '\'' : '')
-                                    . ')';
+                    while ($comments_copy_row
+                        = $GLOBALS['dbi']->fetchAssoc($comments_copy_rs)) {
+                        $new_comment_query = 'REPLACE INTO '
+                            . PMA_Util::backquote($GLOBALS['cfgRelation']['db'])
+                            . '.'
+                            . PMA_Util::backquote(
+                                $GLOBALS['cfgRelation']['column_info']
+                            )
+                            . ' (db_name, table_name, column_name, comment'
+                            . ($GLOBALS['cfgRelation']['mimework']
+                                ? ', mimetype, transformation, transformation_options'
+                                : '')
+                            . ') '
+                            . ' VALUES('
+                            . '\'' . PMA_Util::sqlAddSlashes($target_db)
+                            . '\','
+                            . '\'' . PMA_Util::sqlAddSlashes($target_table)
+                            . '\','
+                            . '\''
+                            . PMA_Util::sqlAddSlashes(
+                                $comments_copy_row['column_name']
+                            )
+                            . '\''
+                            . ($GLOBALS['cfgRelation']['mimework']
+                                ? ',\'' . PMA_Util::sqlAddSlashes($comments_copy_row['comment']) . '\','
+                                    . '\'' . PMA_Util::sqlAddSlashes($comments_copy_row['mimetype']) . '\','
+                                    . '\'' . PMA_Util::sqlAddSlashes($comments_copy_row['transformation']) . '\','
+                                    . '\'' . PMA_Util::sqlAddSlashes($comments_copy_row['transformation_options']) . '\''
+                                : '')
+                            . ')';
                         PMA_queryAsControlUser($new_comment_query);
                     } // end while
                     $GLOBALS['dbi']->freeResult($comments_copy_rs);
@@ -1100,7 +1159,6 @@ class PMA_Table
                     $new_fields
                 );
 
-
                 /**
                  * @todo revise this code when we support cross-db relations
                  */
@@ -1126,7 +1184,6 @@ class PMA_Table
                     $new_fields
                 );
 
-
                 $get_fields = array(
                     'foreign_field',
                     'master_table',
@@ -1149,24 +1206,6 @@ class PMA_Table
                     $new_fields
                 );
 
-
-                $get_fields = array('x', 'y', 'v', 'h');
-                $where_fields = array(
-                    'db_name' => $source_db,
-                    'table_name' => $source_table
-                );
-                $new_fields = array(
-                    'db_name' => $target_db,
-                    'table_name' => $target_table
-                );
-                PMA_Table::duplicateInfo(
-                    'designerwork',
-                    'designer_coords',
-                    $get_fields,
-                    $where_fields,
-                    $new_fields
-                );
-
                 /**
                  * @todo Can't get duplicating PDFs the right way. The
                  * page numbers always get screwed up independently from
@@ -1228,7 +1267,7 @@ class PMA_Table
             return false;
         }
 
-        if (! strlen($table_name)) {
+        if (! /*overload*/mb_strlen($table_name)) {
             // zero length
             return false;
         }
@@ -1303,7 +1342,7 @@ class PMA_Table
                 }
             }
             $this->errors[] = sprintf(
-                __('Error renaming table %1$s to %2$s'),
+                __('Failed to rename table %1$s to %2$s!'),
                 $this->getFullName(),
                 $new_table->getFullName()
             );
@@ -1332,7 +1371,7 @@ class PMA_Table
     /**
      * Get all unique columns
      *
-     * returns an array with all columns with unqiue content, in fact these are
+     * returns an array with all columns with unique content, in fact these are
      * all columns being single indexed in PRIMARY or UNIQUE
      *
      * e.g.
@@ -1364,8 +1403,20 @@ class PMA_Table
             if (count($index) > 1) {
                 continue;
             }
-            $return[] = ($fullName ? $this->getFullName($backquoted) . '.' : '')
-                . ($backquoted ? PMA_Util::backquote($index[0]) : $index[0]);
+            if ($fullName) {
+                $possible_column = $this->getFullName($backquoted) . '.';
+            } else {
+                $possible_column = '';
+            }
+            if ($backquoted) {
+                $possible_column .= PMA_Util::backquote($index[0]);
+            } else {
+                $possible_column .= $index[0];
+            }
+            // a column might have a primary and an unique index on it
+            if (! in_array($possible_column, $return)) {
+                $return[] = $possible_column;
+            }
         }
 
         return $return;
@@ -1374,27 +1425,27 @@ class PMA_Table
     /**
      * Get all indexed columns
      *
-     * returns an array with all columns make use of an index, in fact only
-     * first columns in an index
+     * returns an array with all columns that make use of an index
      *
-     * e.g. index(col1, col2) would only return col1
+     * e.g. index(col1, col2) would return col1, col2
      *
      * @param bool $backquoted whether to quote name with backticks ``
+     * @param bool $fullName   whether to include full name of the table as a prefix
      *
      * @return array
      */
-    public function getIndexedColumns($backquoted = true)
+    public function getIndexedColumns($backquoted = true, $fullName = true)
     {
         $sql = $GLOBALS['dbi']->getTableIndexesSql(
             $this->getDbName(),
             $this->getName(),
-            'Seq_in_index = 1'
+            ''
         );
         $indexed = $GLOBALS['dbi']->fetchResult($sql, 'Column_name', 'Column_name');
 
         $return = array();
         foreach ($indexed as $column) {
-            $return[] = $this->getFullName($backquoted) . '.'
+            $return[] = ($fullName ? $this->getFullName($backquoted) . '.' : '')
                 . ($backquoted ? PMA_Util::backquote($column) : $column);
         }
 
@@ -1431,8 +1482,9 @@ class PMA_Table
      */
     protected function getUiPrefsFromDb()
     {
-        $pma_table = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb']) ."."
-            . PMA_Util::backquote($GLOBALS['cfg']['Server']['table_uiprefs']);
+        $cfgRelation = PMA_getRelationsParam();
+        $pma_table = PMA_Util::backquote($cfgRelation['db']) . "."
+            . PMA_Util::backquote($cfgRelation['table_uiprefs']);
 
         // Read from phpMyAdmin database
         $sql_query = " SELECT `prefs` FROM " . $pma_table
@@ -1455,20 +1507,24 @@ class PMA_Table
      */
     protected function saveUiPrefsToDb()
     {
-        $pma_table = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb']) . "."
-            . PMA_Util::backquote($GLOBALS['cfg']['Server']['table_uiprefs']);
+        $cfgRelation = PMA_getRelationsParam();
+        $pma_table = PMA_Util::backquote($cfgRelation['db']) . "."
+            . PMA_Util::backquote($cfgRelation['table_uiprefs']);
+
+        $secureDbName = PMA_Util::sqlAddSlashes($this->db_name);
 
         $username = $GLOBALS['cfg']['Server']['user'];
         $sql_query = " REPLACE INTO " . $pma_table
-            . " VALUES ('" . $username . "', '" . PMA_Util::sqlAddSlashes($this->db_name)
+            . " (username, db_name, table_name, prefs) VALUES ('"
+            . $username . "', '" . $secureDbName
             . "', '" . PMA_Util::sqlAddSlashes($this->name) . "', '"
-            . PMA_Util::sqlAddSlashes(json_encode($this->uiprefs)) . "', NULL)";
+            . PMA_Util::sqlAddSlashes(json_encode($this->uiprefs)) . "')";
 
         $success = $GLOBALS['dbi']->tryQuery($sql_query, $GLOBALS['controllink']);
 
         if (!$success) {
             $message = PMA_Message::error(
-                __('Could not save table UI preferences')
+                __('Could not save table UI preferences!')
             );
             $message->addMessage('<br /><br />');
             $message->addMessage(
@@ -1524,13 +1580,17 @@ class PMA_Table
      */
     protected function loadUiPrefs()
     {
+        $cfgRelation = PMA_getRelationsParam();
         $server_id = $GLOBALS['server'];
+
         // set session variable if it's still undefined
         if (! isset($_SESSION['tmpval']['table_uiprefs'][$server_id][$this->db_name][$this->name])) {
             // check whether we can get from pmadb
-            $_SESSION['tmpval']['table_uiprefs'][$server_id][$this->db_name][$this->name]
-                = (strlen($GLOBALS['cfg']['Server']['pmadb'])
-                    && strlen($GLOBALS['cfg']['Server']['table_uiprefs']))
+            $_SESSION['tmpval']['table_uiprefs'][$server_id][$this->db_name]
+            [$this->name]
+                = (/*overload*/mb_strlen($cfgRelation['db'])
+                    && /*overload*/mb_strlen($cfgRelation['table_uiprefs'])
+                )
                     ?  $this->getUiPrefsFromDb()
                     : array();
         }
@@ -1558,24 +1618,29 @@ class PMA_Table
         // do checking based on property
         if ($property == self::PROP_SORTED_COLUMN) {
             if (isset($this->uiprefs[$property])) {
-                // check if the column name exists in this table
-                $tmp = explode(' ', $this->uiprefs[$property]);
-                $colname = $tmp[0];               
-                //remove backquoting from colname 
-                $colname = str_replace('`', '', $colname);
-                //get the available column name without backquoting
-                $avail_columns = $this->getColumns(false);
-                foreach ($avail_columns as $each_col) {
-                    // check if $each_col ends with $colname
-                    if (substr_compare(
-                        $each_col,
-                        $colname,
-                        strlen($each_col) - strlen($colname)
-                    ) === 0) {
-                        return $this->uiprefs[$property];
+                if (! isset($_REQUEST['discard_remembered_sort'])) {
+                    // check if the column name exists in this table
+                    $tmp = explode(' ', $this->uiprefs[$property]);
+                    $colname = $tmp[0];
+                    //remove backquoting from colname
+                    $colname = str_replace('`', '', $colname);
+                    //get the available column name without backquoting
+                    $avail_columns = $this->getColumns(false);
+
+                    foreach ($avail_columns as $each_col) {
+                        // check if $each_col ends with $colname
+                        if (substr_compare(
+                            $each_col,
+                            $colname,
+                            /*overload*/mb_strlen($each_col)
+                            - /*overload*/mb_strlen($colname)
+                        ) === 0
+                        ) {
+                            return $this->uiprefs[$property];
+                        }
                     }
                 }
-                // remove the property, since it is not exist anymore in database
+                // remove the property, since it no longer exists in database
                 $this->removeUiProp(self::PROP_SORTED_COLUMN);
                 return false;
             } else {
@@ -1655,9 +1720,11 @@ class PMA_Table
         }
         // save the value
         $this->uiprefs[$property] = $value;
+
         // check if pmadb is set
-        if (strlen($GLOBALS['cfg']['Server']['pmadb'])
-            && strlen($GLOBALS['cfg']['Server']['table_uiprefs'])
+        $cfgRelation = PMA_getRelationsParam();
+        if (/*overload*/mb_strlen($cfgRelation['db'])
+            && /*overload*/mb_strlen($cfgRelation['table_uiprefs'])
         ) {
             return $this->saveUiprefsToDb();
         }
@@ -1678,9 +1745,11 @@ class PMA_Table
         }
         if (isset($this->uiprefs[$property])) {
             unset($this->uiprefs[$property]);
+
+            $cfgRelation = PMA_getRelationsParam();
             // check if pmadb is set
-            if (strlen($GLOBALS['cfg']['Server']['pmadb'])
-                && strlen($GLOBALS['cfg']['Server']['table_uiprefs'])
+            if (/*overload*/mb_strlen($cfgRelation['db'])
+                && /*overload*/mb_strlen($cfgRelation['table_uiprefs'])
             ) {
                 return $this->saveUiprefsToDb();
             }
