@@ -10,23 +10,12 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-require_once './libraries/logging.lib.php';
 require_once './libraries/dbi/DBIExtension.int.php';
 
 /**
  * MySQL client API
  */
-if (! defined('PMA_MYSQL_CLIENT_API')) {
-    $client_api = explode('.', mysql_get_client_info());
-    define(
-        'PMA_MYSQL_CLIENT_API',
-        (int)sprintf(
-            '%d%02d%02d',
-            $client_api[0], $client_api[1], intval($client_api[2])
-        )
-    );
-    unset($client_api);
-}
+PMA_defineClientAPI(mysql_get_client_info());
 
 /**
  * Interface to the classic MySQL extension
@@ -39,11 +28,11 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
     /**
      * Helper function for connecting to the database server
      *
-     * @param array  $server       host/port/socket
+     * @param string $server       host/port/socket
      * @param string $user         mysql user name
      * @param string $password     mysql user password
      * @param int    $client_flags client flags of connection
-     * @param bool   $persistent   whether to use peristent connection
+     * @param bool   $persistent   whether to use persistent connection
      *
      * @return mixed   false on error or a mysql connection resource on success
      */
@@ -77,7 +66,7 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
      * @param mysqli $link  mysqli object
      * @param string $query multi query statement to execute
      *
-     * @return boolean false always false since mysql extention not support
+     * @return boolean false always false since mysql extension not support
      *                       for multi query executions
      */
     public function realMultiQuery($link, $query)
@@ -107,20 +96,19 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
     ) {
         global $cfg;
 
-        if ($server) {
-            $server_port = (empty($server['port']))
-                ? ''
-                : ':' . (int)$server['port'];
-            $server_socket = (empty($server['socket']))
-                ? ''
-                : ':' . $server['socket'];
+        $server_port = $GLOBALS['dbi']->getServerPort($server);
+        $server_socket = $GLOBALS['dbi']->getServerSocket($server);
+
+        if ($server_port === null) {
+            $server_port = '';
         } else {
-            $server_port   = (empty($cfg['Server']['port']))
-                ? ''
-                : ':' . (int)$cfg['Server']['port'];
-            $server_socket = (empty($cfg['Server']['socket']))
-                ? ''
-                : ':' . $cfg['Server']['socket'];
+            $server_port = ':' . $server_port;
+        }
+
+        if (is_null($server_socket)) {
+            $server_socket = '';
+        } else {
+            $server_socket = ':' . $server_socket;
         }
 
         $client_flags = 0;
@@ -163,60 +151,28 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
                 );
             }
         }
-        if (empty($link)) {
-            if ($is_controluser) {
-                trigger_error(
-                    __(
-                        'Connection for controluser as defined'
-                        . ' in your configuration failed.'
-                    ),
-                    E_USER_WARNING
-                );
-                return false;
-            }
-            // we could be calling $GLOBALS['dbi']->connect() to connect to another
-            // server, for example in the Synchronize feature, so do not
-            // go back to main login if it fails
-            if (! $auxiliary_connection) {
-                PMA_logUser($user, 'mysql-denied');
-                global $auth_plugin;
-                $auth_plugin->authFails();
-            } else {
-                return false;
-            }
-        } // end if
-        if (! $server) {
-            $GLOBALS['dbi']->postConnect($link, $is_controluser);
-        }
         return $link;
     }
 
     /**
      * selects given database
      *
-     * @param string   $dbname name of db to select
-     * @param resource $link   mysql link resource
+     * @param string        $dbname name of db to select
+     * @param resource|null $link   mysql link resource
      *
      * @return bool
      */
-    public function selectDb($dbname, $link = null)
+    public function selectDb($dbname, $link)
     {
-        if (empty($link)) {
-            if (isset($GLOBALS['userlink'])) {
-                $link = $GLOBALS['userlink'];
-            } else {
-                return false;
-            }
-        }
         return mysql_select_db($dbname, $link);
     }
 
     /**
      * runs a query and returns the result
      *
-     * @param string   $query   query to run
-     * @param resource $link    mysql link resource
-     * @param int      $options query options
+     * @param string        $query   query to run
+     * @param resource|null $link    mysql link resource
+     * @param int           $options query options
      *
      * @return mixed
      */
@@ -301,7 +257,7 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
      *
      * @return bool false
      */
-    public function moreResults($link = null)
+    public function moreResults($link)
     {
         // N.B.: PHP's 'mysql' extension does not support
         // multi_queries so this function will always
@@ -317,7 +273,7 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
      *
      * @return boolean false
      */
-    public function nextResult($link = null)
+    public function nextResult($link)
     {
         // N.B.: PHP's 'mysql' extension does not support
         // multi_queries so this function will always
@@ -329,38 +285,24 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
     /**
      * Returns a string representing the type of connection used
      *
-     * @param resource $link mysql link
+     * @param resource|null $link mysql link
      *
      * @return string type of connection used
      */
-    public function getHostInfo($link = null)
+    public function getHostInfo($link)
     {
-        if (null === $link) {
-            if (isset($GLOBALS['userlink'])) {
-                $link = $GLOBALS['userlink'];
-            } else {
-                return false;
-            }
-        }
         return mysql_get_host_info($link);
     }
 
     /**
      * Returns the version of the MySQL protocol used
      *
-     * @param resource $link mysql link
+     * @param resource|null $link mysql link
      *
      * @return int version of the MySQL protocol used
      */
-    public function getProtoInfo($link = null)
+    public function getProtoInfo($link)
     {
-        if (null === $link) {
-            if (isset($GLOBALS['userlink'])) {
-                $link = $GLOBALS['userlink'];
-            } else {
-                return false;
-            }
-        }
         return mysql_get_proto_info($link);
     }
 
@@ -377,28 +319,14 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
     /**
      * returns last error message or false if no errors occurred
      *
-     * @param resource $link mysql link
+     * @param resource|null $link mysql link
      *
      * @return string|bool $error or false
      */
-    public function getError($link = null)
+    public function getError($link)
     {
         $GLOBALS['errno'] = 0;
 
-        /* Treat false same as null because of controllink */
-        if ($link === false) {
-            $link = null;
-        }
-
-        if (null === $link && isset($GLOBALS['userlink'])) {
-            $link =& $GLOBALS['userlink'];
-
-            // Do not stop now. On the initial connection, we don't have a $link,
-            // we don't have a $GLOBALS['userlink'], but we can catch the error code
-            //    } else {
-            //            return false;
-        }
-
         if (null !== $link && false !== $link) {
             $error_number = mysql_errno($link);
             $error_message = mysql_error($link);
@@ -433,54 +361,16 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
         return mysql_num_rows($result);
     }
 
-    /**
-     * returns last inserted auto_increment id for given $link
-     * or $GLOBALS['userlink']
-     *
-     * @param resource $link the mysql object
-     *
-     * @return string|int
-     */
-    public function insertId($link = null)
-    {
-        if (empty($link)) {
-            if (isset($GLOBALS['userlink'])) {
-                $link = $GLOBALS['userlink'];
-            } else {
-                return false;
-            }
-        }
-        // If the primary key is BIGINT we get an incorrect result
-        // (sometimes negative, sometimes positive)
-        // and in the present function we don't know if the PK is BIGINT
-        // so better play safe and use LAST_INSERT_ID()
-        //
-        return $GLOBALS['dbi']->fetchValue('SELECT LAST_INSERT_ID();', 0, 0, $link);
-    }
-
     /**
      * returns the number of rows affected by last query
      *
-     * @param resource $link           the mysql object
-     * @param bool     $get_from_cache whether to retrieve from cache
+     * @param resource|null $link the mysql object
      *
-     * @return string|int
+     * @return int
      */
-    public function affectedRows($link = null, $get_from_cache = true)
+    public function affectedRows($link)
     {
-        if (empty($link)) {
-            if (isset($GLOBALS['userlink'])) {
-                $link = $GLOBALS['userlink'];
-            } else {
-                return false;
-            }
-        }
-
-        if ($get_from_cache) {
-            return $GLOBALS['cached_affected_rows'];
-        } else {
-            return mysql_affected_rows($link);
-        }
+        return mysql_affected_rows($link);
     }
 
     /**
@@ -560,11 +450,13 @@ class PMA_DBI_Mysql implements PMA_DBI_Extension
     /**
      * Store the result returned from multi query
      *
+     * @param resource $result MySQL result
+     *
      * @return false
      */
-    public function storeResult()
+    public function storeResult($result)
     {
         return false;
     }
 }
-?>
\ No newline at end of file
+?>
