@@ -96,21 +96,15 @@ function PMA_TRI_handleEditor()
                         // We dropped the old item, but were unable to create the
                         // new one. Try to restore the backup query.
                         $result = $GLOBALS['dbi']->tryQuery($create_item);
-                        if (! $result) {
-                            // OMG, this is really bad! We dropped the query,
-                            // failed to create a new one
-                            // and now even the backup query does not execute!
-                            // This should not happen, but we better handle
-                            // this just in case.
-                            $errors[] = __(
+
+                        $errors = checkResult(
+                            $result,
+                            __(
                                 'Sorry, we failed to restore the dropped trigger.'
-                            )
-                            . '<br />'
-                            . __('The backed up query was:')
-                            . "\"" . htmlspecialchars($create_item) . "\""
-                            . '<br />'
-                            . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
-                        }
+                            ),
+                            $create_item,
+                            $errors
+                        );
                     } else {
                         $message = PMA_Message::success(
                             __('Trigger %1$s has been modified.')
@@ -144,7 +138,13 @@ function PMA_TRI_handleEditor()
         }
 
         if (count($errors)) {
-            $message = PMA_Message::error(__('<b>One or more errors have occurred while processing your request:</b>'));
+            $message = PMA_Message::error(
+                '<b>'
+                . __(
+                    'One or more errors have occurred while processing your request:'
+                )
+                . '</b>'
+            );
             $message->addString('<ul>');
             foreach ($errors as $string) {
                 $message->addString('<li>' . $string . '</li>');
@@ -172,7 +172,9 @@ function PMA_TRI_handleEditor()
                     $response->addJSON(
                         'name',
                         htmlspecialchars(
-                            strtoupper($_REQUEST['item_name'])
+                            /*overload*/mb_strtoupper(
+                                $_REQUEST['item_name']
+                            )
                         )
                     );
                 }
@@ -214,35 +216,7 @@ function PMA_TRI_handleEditor()
             }
             $mode = 'edit';
         }
-        if ($item !== false) {
-            // Show form
-            $editor = PMA_TRI_getEditorForm($mode, $item);
-            if ($GLOBALS['is_ajax_request']) {
-                $response = PMA_Response::getInstance();
-                $response->addJSON('message', $editor);
-                $response->addJSON('title', $title);
-            } else {
-                echo "\n\n<h2>$title</h2>\n\n$editor";
-                unset($_POST);
-            }
-            exit;
-        } else {
-            $message  = __('Error in processing request:') . ' ';
-            $message .= sprintf(
-                PMA_RTE_getWord('not_found'),
-                htmlspecialchars(PMA_Util::backquote($_REQUEST['item_name'])),
-                htmlspecialchars(PMA_Util::backquote($db))
-            );
-            $message = PMA_message::error($message);
-            if ($GLOBALS['is_ajax_request']) {
-                $response = PMA_Response::getInstance();
-                $response->isSuccess(false);
-                $response->addJSON('message', $message);
-                exit;
-            } else {
-                $message->display();
-            }
-        }
+        PMA_RTE_sendEditor('TRI', $mode, $item, $title, $db);
     }
 } // end PMA_TRI_handleEditor()
 
@@ -316,6 +290,8 @@ function PMA_TRI_getEditorForm($mode, $item)
 {
     global $db, $table, $event_manipulations, $action_timings;
 
+    $modeToUpper = /*overload*/mb_strtoupper($mode);
+
     // Escape special characters
     $need_escape = array(
                        'item_original_name',
@@ -338,7 +314,7 @@ function PMA_TRI_getEditorForm($mode, $item)
 
     // Create the output
     $retval  = "";
-    $retval .= "<!-- START " . strtoupper($mode) . " TRIGGER FORM -->\n\n";
+    $retval .= "<!-- START " . $modeToUpper . " TRIGGER FORM -->\n\n";
     $retval .= "<form class='rte_form' action='db_triggers.php' method='post'>\n";
     $retval .= "<input name='{$mode}_item' type='hidden' value='1' />\n";
     $retval .= $original_data;
@@ -421,7 +397,7 @@ function PMA_TRI_getEditorForm($mode, $item)
         $retval .= "</fieldset>\n";
     }
     $retval .= "</form>\n\n";
-    $retval .= "<!-- END " . strtoupper($mode) . " TRIGGER FORM -->\n\n";
+    $retval .= "<!-- END " . $modeToUpper . " TRIGGER FORM -->\n\n";
 
     return $retval;
 } // end PMA_TRI_getEditorForm()
@@ -437,33 +413,34 @@ function PMA_TRI_getQueryFromRequest()
 
     $query = 'CREATE ';
     if (! empty($_REQUEST['item_definer'])) {
-        if (strpos($_REQUEST['item_definer'], '@') !== false) {
+        if (/*overload*/mb_strpos($_REQUEST['item_definer'], '@') !== false
+        ) {
             $arr = explode('@', $_REQUEST['item_definer']);
             $query .= 'DEFINER=' . PMA_Util::backquote($arr[0]);
             $query .= '@' . PMA_Util::backquote($arr[1]) . ' ';
         } else {
-            $errors[] = __('The definer must be in the "username@hostname" format');
+            $errors[] = __('The definer must be in the "username@hostname" format!');
         }
     }
     $query .= 'TRIGGER ';
     if (! empty($_REQUEST['item_name'])) {
         $query .= PMA_Util::backquote($_REQUEST['item_name']) . ' ';
     } else {
-        $errors[] = __('You must provide a trigger name');
+        $errors[] = __('You must provide a trigger name!');
     }
     if (! empty($_REQUEST['item_timing'])
         && in_array($_REQUEST['item_timing'], $action_timings)
     ) {
         $query .= $_REQUEST['item_timing'] . ' ';
     } else {
-        $errors[] = __('You must provide a valid timing for the trigger');
+        $errors[] = __('You must provide a valid timing for the trigger!');
     }
     if (! empty($_REQUEST['item_event'])
         && in_array($_REQUEST['item_event'], $event_manipulations)
     ) {
         $query .= $_REQUEST['item_event'] . ' ';
     } else {
-        $errors[] = __('You must provide a valid event for the trigger');
+        $errors[] = __('You must provide a valid event for the trigger!');
     }
     $query .= 'ON ';
     if (! empty($_REQUEST['item_table'])
@@ -471,7 +448,7 @@ function PMA_TRI_getQueryFromRequest()
     ) {
         $query .= PMA_Util::backquote($_REQUEST['item_table']);
     } else {
-        $errors[] = __('You must provide a valid table name');
+        $errors[] = __('You must provide a valid table name!');
     }
     $query .= ' FOR EACH ROW ';
     if (! empty($_REQUEST['item_definition'])) {
